/**
 * File Name: Boot.js
 * File URL: http://www.renown-games.com/MozartMusicMatch/
 * Description: File for controlling and displaying game scenes; managing global variables throughout game state.
 * Author: Stephen Gose
 * Version: 0.0.0.15
 * Author URL: http://www.stephen-gose.com/
 * Support: support@pbmcube.com
 *
 * Copyright  2008-2016 Stephen Gose LLC. All rights reserved. 
 * 
 * Do not sell! Do not distribute!
 * This is a licensed permission file. Please refer to Terms of Use
 *   and End Users License Agreement (EULA).
 * Search for [ //**TODO** ] to tailor this file for your own use and will void any support agreement.
 *
 * Redistribution of part or whole of this file and
 * the accompanying files is strictly prohibited.
 *
 */

/**
Reason for using prototypes in Phaser: (See "Detour" Section) https://www.joshmorony.com/mobile-development-for-web-developers/getting-started-with-phaser.html
*/
mmm.Boot = function (game) {
};

/**
Every object in JavaScript has a specially related object called the prototype. Prototypes are a simple way to share code behaviour and data amoung objects.

Read: 
- http://sporto.github.io/blog/2013/02/22/a-plain-english-guide-to-javascript-prototypes/

- https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Classes

REMEMBER: ES6 classes in JavaScript are not blueprints as found in other languages. They are simply "defined objects" that are modified "at will" during runtime.

*/

mmm.Boot.prototype = {

    init: function () {

        this.input.maxPointers = 1;
        this.stage.disableVisibilityChange = true;
        this.scale.scaleMode = Phaser.ScaleManager.SHOW_ALL;
        this.scale.setMinMax(480, 300, 1024, 640);	//Golden Rations
        this.scale.pageAlignHorizontally = true;	//centered horizontally
        this.scale.pageAlignVertically = true;		//centered vertically

		this.scale.setShowAll();
		this.scale.refresh();

        if (!this.game.device.desktop)
        {
            this.scale.forceOrientation(true, false);
            this.scale.setResizeCallback(this.gameResized, this);
            this.scale.enterIncorrectOrientation.add(this.enterIncorrectOrientation, this);
            this.scale.leaveIncorrectOrientation.add(this.leaveIncorrectOrientation, this);
        }

    },

    preload: function () {
		this.load.audio('titleMusic', ['audio/main_menu.mp3']);
		this.load.image('preloaderBackground', 'icons/largetile.png');	//splash screen
		this.load.image('preloaderBar', 'images/preloadbar.png'); 		//loader bar
		
		//game background;static title and copyright on mmmMenu-org.jpg
		this.load.image('gamebkgrnd', 'images/mmmMenu-org.jpg'); 
		this.load.spritesheet('button', 'images/buttons/mmm-sprites.png', 129, 30);
		this.load.spritesheet('soundButton', 'images/buttons/soundButton.png', 28, 35);
		
		//Audio Game #1 sfx preloaded; we have game sound assets available for any browser.
		this.load.audio('notepair_01', ['audio/notepair_01.mp3','audio/notepair_01.ogg']);
		this.load.audio('notepair_02', ['audio/notepair_02.mp3','audio/notepair_02.ogg']);
		this.load.audio('notepair_03', ['audio/notepair_03.mp3','audio/notepair_03.ogg']);
		this.load.audio('notepair_04', ['audio/notepair_04.mp3','audio/notepair_04.ogg']);
		this.load.audio('notepair_05', ['audio/notepair_05.mp3','audio/notepair_05.ogg']);
		this.load.audio('notepair_06', ['audio/notepair_06.mp3','audio/notepair_06.ogg']);
		this.load.audio('notepair_07', ['audio/notepair_07.mp3','audio/notepair_07.ogg']);
		this.load.audio('notepair_08', ['audio/notepair_08.mp3','audio/notepair_08.ogg']);
    },

    create: function () {
		//move to the next game phase state
		this.state.start('Preloader');

    },

	//
    gameResized: function (width, height) {
	//https://www.joshmorony.com/how-to-scale-a-game-for-all-device-sizes-in-phaser/
		
	//Phaser Full Screen Mobile Template Notes:
	//  This could be handy if you need to do any extra processing if the game resizes.
	//  A resize could happen if for example swapping orientation on a device or resizing the browser window.
	//  Note that this callback is only really useful if you use a ScaleMode of RESIZE and place it inside your main game state.

    },

    enterIncorrectOrientation: function () {

        mmm.orientated = false;

        document.getElementById('orientation').style.display = 'block';

    },

    leaveIncorrectOrientation: function () {

        mmm.orientated = true;

        document.getElementById('orientation').style.display = 'none';

    }

};
